# libpytools
Módulo para exemplificar construção de projetos Python.

Neste módulo é mostrado como contribuir com códigos opensource.

Link do curso: [Python Pro](http://python.pro.br/)

[![Build Status](https://travis-ci.org/gabrieldcpadilha/libpytools.svg?branch=main)](https://travis-ci.org/gabrieldcpadilha/libpytools)
[![Updates](https://pyup.io/repos/github/gabrieldcpadilha/libpytools/shield.svg)](https://pyup.io/repos/github/gabrieldcpadilha/libpytools/)
[![Python 3](https://pyup.io/repos/github/gabrieldcpadilha/libpytools/python-3-shield.svg)](https://pyup.io/repos/github/gabrieldcpadilha/libpytools/)

Para instalar:
```console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requiments-dev.txt
```

Para conferir a qualidade do código:
```console
flake8
```

Tópicos abordados:

1. Git
2. Virtualenv
3. Pip
